/*********************************************************************************************************
* Software License Agreement (BSD License)                                                               *
* Author: Sebastien Decugis <sdecugis@nict.go.jp>							 *
*													 *
* Copyright (c) 2008, WIDE Project and NICT								 *
* All rights reserved.											 *
* 													 *
* Redistribution and use of this software in source and binary forms, with or without modification, are  *
* permitted provided that the following conditions are met:						 *
* 													 *
* * Redistributions of source code must retain the above 						 *
*   copyright notice, this list of conditions and the 							 *
*   following disclaimer.										 *
*    													 *
* * Redistributions in binary form must reproduce the above 						 *
*   copyright notice, this list of conditions and the 							 *
*   following disclaimer in the documentation and/or other						 *
*   materials provided with the distribution.								 *
* 													 *
* * Neither the name of the WIDE Project or NICT nor the 						 *
*   names of its contributors may be used to endorse or 						 *
*   promote products derived from this software without 						 *
*   specific prior written permission of WIDE Project and 						 *
*   NICT.												 *
* 													 *
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED *
* WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A *
* PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR *
* ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 	 *
* LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 	 *
* INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR *
* TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF   *
* ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.								 *
*********************************************************************************************************/
/* 
 * Main file of the radius_gw extension.
 */

#define DECLARE_API_POINTERS
#include "radius_gw_internal.h"

int radius_gw_verbosity = 0;

static int rgw_init(void)
{
	int ret = 0;
	ret = rgw_servers_init();
	if (ret != 0) {
		TRACE_DEBUG(INFO, "Error in servers initialization: %s", strerror(ret));
		return ret;
	}
	
	ret = rgw_clients_init();
	if (ret != 0) {
		TRACE_DEBUG(INFO, "Error in clients initialization: %s", strerror(ret));
		return ret;
	}
	
	ret = rgw_extensions_init();
	if (ret != 0) {
		TRACE_DEBUG(INFO, "Error in extensions initialization: %s", strerror(ret));
		return ret;
	}
	
	return 0;
}

static int rgw_entry(char * conffile) 
{
	int ret = 0;
	
	ret = rgw_init();
	if (ret != 0) {
		log_error("Error in extension initialization: %s\n", strerror(ret));
		return ret;
	}
	
	ret = rgw_conf_handle(conffile);
	if (ret != 0) {
		log_error("Error while parsin the configuration: %s\n", strerror(ret));
		return ret;
	}
		
	TRACE_DEBUG(FULL, "-------------------------");
	rgw_servers_dump();
	rgw_clients_dump();
	rgw_extensions_dump();
	TRACE_DEBUG(FULL, "-------------------------");
	
	
	return ret;
}

/* Unload */
void waaad_ext_fini(void)
{
	rgw_servers_fini();
	rgw_extensions_fini();
	rgw_clients_fini();
}

EXTENSION_API_INIT( API_MODULE_ALL, rgw_entry, "radius_gw" );
